eprllib.RewardFunctions — eprllib: use EnergyPlus as an environment for DRL control

Skip to main content
`Ctrl`+`K`

# eprllib.RewardFunctions

## Reward functions in eprllib

The reward functions are called in the `step()` method in the environment iteratively for each agent present in the respective timestep.

In this module contain the reward functions used in the reinforcement learning and implemented in eprllib.

You can implement your own reward function by creating a new class that inherits from `RewardFunction` and overriding the `calculate_reward` method.

Modules

`RewardFunctions` | Reward Funtion
`comfort_rewards` | Comfort rewards
`energy_and_ashrae55simplemodel` | Energy and ASHRAE 55 Simple Model reward function
`energy_and_cen15251` | Energy and CEN 15251 reward function
`energy_rewards` | Energy rewards